from setuptools import setup

setup(name='gauss_binom_distributions_patwrz',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gauss_binom_distributions_patwrz'],
      author = 'Patrycja Wrzosek',
      zip_safe=False)
